Welcome to mirror list, hosted at ThFree Co, Russian Federation.

cygwin.com/git/newlib-cygwin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--include/ChangeLog4
-rw-r--r--include/bfdlink.h7
2 files changed, 10 insertions, 1 deletions
diff --git a/include/ChangeLog b/include/ChangeLog
index de51a8fbb..7de9f244a 100644
--- a/include/ChangeLog
+++ b/include/ChangeLog
@@ -1,3 +1,7 @@
+2004-11-04 Paul Brook <paul@codesourcery.com>
+
+ * bfdlink.h (bfd_link_info): Add default_imported_symver.
+
2004-11-12 Bob Wilson <bob.wilson@acm.org>
* xtensa-isa-internal.h (xtensa_interface_internal): Add class_id.
diff --git a/include/bfdlink.h b/include/bfdlink.h
index ab59b7c78..9950920a3 100644
--- a/include/bfdlink.h
+++ b/include/bfdlink.h
@@ -262,9 +262,14 @@ struct bfd_link_info
/* TRUE if ok to have version with no definition. */
unsigned int allow_undefined_version: 1;
- /* TRUE id a fedault symbol version should be created and used. */
+ /* TRUE if a default symbol version should be created and used for
+ exported symbols. */
unsigned int create_default_symver: 1;
+ /* TRUE if a default symbol version should be created and used for
+ imported symbols. */
+ unsigned int default_imported_symver: 1;
+
/* TRUE if symbols should be retained in memory, FALSE if they
should be freed and reread. */
unsigned int keep_memory: 1;